@@ -27,11 +27,13 @@ class SKOSOptions(KnowledgeParserOptions):
     """
     rdf_format: RDFFormat = Query(RDFFormat.xml, description="RDF format")
 
+
 SKOSOptionsModel = SKOSOptions.__pydantic_model__
 
 
 class SKOSKnowledgeParser(KnowledgeParserBase):
-    def parse(self, source : Path, options: Union[KnowledgeParserOptions, Dict[str, Any]], bar : Bar) -> Generator[Term, None, None]:
+    def parse(self, source: Path, options: Union[KnowledgeParserOptions, Dict[str, Any]], bar: Bar) \
+            -> Generator[Term, None, None]:
         options = SKOSOptions(**options) if isinstance(options, dict) else options
         bar.max = 20
         bar.start()
